@@ -2298,23 +2298,10 @@ const v8::Value* v8__Module__GetException(const v8::Module& self) {
   return local_to_ptr(self.GetException());
 }
 
-int v8__Module__GetModuleRequestsLength(const v8::Module& self) {
-  return self.GetModuleRequestsLength();
-}
-
-const v8::String* v8__Module__GetModuleRequest(const v8::Module& self, int i) {
-  return local_to_ptr(self.GetModuleRequest(i));
-}
-
 const v8::FixedArray* v8__Module__GetModuleRequests(const v8::Module& self) {
   return local_to_ptr(self.GetModuleRequests());
 }
 
-void v8__Module__GetModuleRequestLocation(const v8::Module& self, int i,
-                                          v8::Location* out) {
-  *out = self.GetModuleRequestLocation(i);
-}
-
 void v8__Module__SourceOffsetToLocation(const v8::Module& self, int offset,
                                         v8::Location* out) {
   *out = self.SourceOffsetToLocation(offset);
@@ -2463,7 +2450,7 @@ void v8__HeapProfiler__TakeHeapSnapshot(v8::Isolate* isolate,
 
 // This is necessary for v8__internal__GetIsolateFromHeapObject() to be
 // reliable enough for our purposes.
-#if !(defined V8_SHARED_RO_HEAP or defined V8_COMPRESS_POINTERS)
+#if UINTPTR_MAX == 0xffffffffffffffff && !(defined V8_SHARED_RO_HEAP or defined V8_COMPRESS_POINTERS)
 #error V8 must be built with either the 'v8_enable_pointer_compression' or \
 'v8_enable_shared_ro_heap' feature enabled.
 #endif
@@ -2564,8 +2551,11 @@ struct v8__ValueSerializer__Delegate : public v8::ValueSerializer::Delegate {
       v8::Local<v8::SharedArrayBuffer> shared_array_buffer) override {
     uint32_t result = 0;
     if (!v8__ValueSerializer__Delegate__GetSharedArrayBufferId(
-            this, isolate, shared_array_buffer, &result))
-      return v8::Nothing<uint32_t>();
+            this, isolate, shared_array_buffer, &result)) {
+      // Forward to the original method. It'll throw DataCloneError.
+      return v8::ValueSerializer::Delegate::GetSharedArrayBufferId(
+          isolate, shared_array_buffer);
+    }
     return v8::Just(result);
   }
 
@@ -2760,3 +2750,28 @@ bool v8__ValueDeserializer__ReadRawBytes(v8::ValueDeserializer* self,
   return self->ReadRawBytes(length, data);
 }
 }  // extern "C"
+
+// v8::CompiledWasmModule
+
+extern "C" {
+const v8::WasmModuleObject* v8__WasmModuleObject__FromCompiledModule(v8::Isolate* isolate,
+                                                                     const v8::CompiledWasmModule* compiled_module) {
+  return maybe_local_to_ptr(v8::WasmModuleObject::FromCompiledModule(isolate, *compiled_module));
+}
+
+v8::CompiledWasmModule* v8__WasmModuleObject__GetCompiledModule(const v8::WasmModuleObject* self) {
+  v8::CompiledWasmModule cwm = ptr_to_local(self)->GetCompiledModule();
+  return new v8::CompiledWasmModule(std::move(cwm));
+}
+
+const uint8_t* v8__CompiledWasmModule__GetWireBytesRef(v8::CompiledWasmModule* self,
+                                                       size_t* length) {
+  v8::MemorySpan<const uint8_t> span = self->GetWireBytesRef();
+  *length = span.size();
+  return span.data();
+}
+
+void v8__CompiledWasmModule__DELETE(v8::CompiledWasmModule* self) {
+  delete self;
+}
+}  // extern "C"
\ No newline at end of file
